package com.ruoyi.generator.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.generator.domain.SysCodeSnippet;
import com.ruoyi.generator.service.ISysCodeSnippetService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 代码片段管理Controller
 * 
 * @author ruoyi
 * @date 2025-05-09
 */
@RestController
@RequestMapping("/generator/snippet")
public class SysCodeSnippetController extends BaseController
{
    @Autowired
    private ISysCodeSnippetService sysCodeSnippetService;

    /**
     * 查询代码片段管理列表
     */
    @PreAuthorize("@ss.hasPermi('generator:snippet:list')")
    @GetMapping("/list")
    public TableDataInfo list(SysCodeSnippet sysCodeSnippet)
    {
        startPage();
        List<SysCodeSnippet> list = sysCodeSnippetService.selectSysCodeSnippetList(sysCodeSnippet);
        return getDataTable(list);
    }

    /**
     * 导出代码片段管理列表
     */
    @PreAuthorize("@ss.hasPermi('generator:snippet:export')")
    @Log(title = "代码片段管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysCodeSnippet sysCodeSnippet)
    {
        List<SysCodeSnippet> list = sysCodeSnippetService.selectSysCodeSnippetList(sysCodeSnippet);
        ExcelUtil<SysCodeSnippet> util = new ExcelUtil<SysCodeSnippet>(SysCodeSnippet.class);
        util.exportExcel(response, list, "代码片段管理数据");
    }

    /**
     * 获取代码片段管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('generator:snippet:query')")
    @GetMapping(value = "/{snippetId}")
    public AjaxResult getInfo(@PathVariable("snippetId") Long snippetId)
    {
        return success(sysCodeSnippetService.selectSysCodeSnippetBySnippetId(snippetId));
    }

    /**
     * 新增代码片段管理
     */
    @PreAuthorize("@ss.hasPermi('generator:snippet:add')")
    @Log(title = "代码片段管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SysCodeSnippet sysCodeSnippet)
    {
        return toAjax(sysCodeSnippetService.insertSysCodeSnippet(sysCodeSnippet));
    }

    /**
     * 修改代码片段管理
     */
    @PreAuthorize("@ss.hasPermi('generator:snippet:edit')")
    @Log(title = "代码片段管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SysCodeSnippet sysCodeSnippet)
    {
        return toAjax(sysCodeSnippetService.updateSysCodeSnippet(sysCodeSnippet));
    }

    /**
     * 删除代码片段管理
     */
    @PreAuthorize("@ss.hasPermi('generator:snippet:remove')")
    @Log(title = "代码片段管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{snippetIds}")
    public AjaxResult remove(@PathVariable Long[] snippetIds)
    {
        return toAjax(sysCodeSnippetService.deleteSysCodeSnippetBySnippetIds(snippetIds));
    }
}
